@@ -9,7 +9,9 @@ from ..cli.dag import dag
 from ..cli.dryrun import dryrun
 from ..cli.format import format
 from ..cli.udf import udf, mozfun
+from ..glam.cli import glam
 from .._version import __version__
+from ..stripe import stripe_
 
 
 def cli():
@@ -21,6 +23,8 @@ def cli():
         "format": format,
         "udf": udf,
         "mozfun": mozfun,
+        "stripe": stripe_,
+        "glam": glam,
     }
 
     @click.group(commands=commands)
