@@ -20,6 +20,7 @@ UDF_DIRS = ("udf", "udf_js")
 MOZFUN_DIR = ("mozfun",)
 UDF_CHAR = "[a-zA-z0-9_]"
 UDF_FILE = "udf.sql"
+PROCEDURE_FILE = "stored_procedure.sql"
 EXAMPLE_DIR = "examples"
 TEMP_UDF_RE = re.compile(f"(?:udf|assert)_{UDF_CHAR}+")
 PERSISTENT_UDF_RE = re.compile(fr"((?:udf|assert){UDF_CHAR}*)\.({UDF_CHAR}+)")
@@ -28,15 +29,19 @@ PERSISTENT_UDF_PREFIX = re.compile(
     r"CREATE\s+(OR\s+REPLACE\s+)?FUNCTION(\s+IF\s+NOT\s+EXISTS)?", re.IGNORECASE
 )
 UDF_NAME_RE = re.compile(r"^([a-zA-Z0-9_]+\.)?[a-zA-Z][a-zA-Z0-9_]{0,255}$")
+GENERIC_DATASET = "_generic_dataset_"
 
 # UDFs defined in mozfun
-MOZFUN_UDFS = {
-    root.split("/")[-2] + "." + root.split("/")[-1]
+MOZFUN_ROUTINES = [
+    {
+        "name": root.split("/")[-2] + "." + root.split("/")[-1],
+        "is_udf": filename == UDF_FILE,
+    }
     for udf_dir in MOZFUN_DIR
     for root, dirs, files in os.walk(udf_dir)
     for filename in files
-    if filename == UDF_FILE
-}
+    if filename in (UDF_FILE, PROCEDURE_FILE)
+]
 
 
 @dataclass
@@ -50,6 +55,7 @@ class RawUdf:
     tests: List[str]
     dependencies: List[str]
     description: str  # description from metadata file
+    is_stored_procedure: str
 
     @staticmethod
     def from_file(filepath):
@@ -88,11 +94,14 @@ class RawUdf:
         persistent_name = f"{dataset}.{name}"
         temp_name = f"{dataset}_{name}"
         internal_name = None
+        is_stored_procedure = False
 
         definitions = []
         tests = []
 
-        for s in statements:
+        procedure_start = -1
+
+        for i, s in enumerate(statements):
             normalized_statement = " ".join(s.lower().split())
             if normalized_statement.startswith("create or replace function"):
                 definitions.append(s)
@@ -104,10 +113,30 @@ class RawUdf:
                 if temp_name in normalized_statement:
                     internal_name = temp_name
 
-            else:
+            elif normalized_statement.startswith("create or replace procedure"):
+                is_stored_procedure = True
+                definitions.append(s)
                 tests.append(s)
+                if persistent_name in normalized_statement:
+                    internal_name = persistent_name
+
+            else:
+                if normalized_statement.startswith("begin"):
+                    procedure_start = i
+
+                if procedure_start == -1:
+                    tests.append(s)
+
+                if procedure_start > -1 and normalized_statement.endswith("end;"):
+                    tests.append(" ".join(statements[procedure_start : i + 1]))
+                    procedure_start = -1
 
         for name in (prod_name, internal_name):
+            if name is None:
+                raise ValueError(
+                    f"Expected a function named {persistent_name} or {temp_name} "
+                    f"to be defined"
+                )
             if is_defined and not UDF_NAME_RE.match(name):
                 raise ValueError(
                     f"Invalid UDF name {name}: Must start with alpha char, "
@@ -122,16 +151,11 @@ class RawUdf:
         # for public UDFs dependencies can live in arbitrary dataset;
         # we can check if some known dependency is part of the UDF
         # definition instead
-        for udf in MOZFUN_UDFS:
-            if udf in "\n".join(definitions):
-                dependencies.append(udf)
+        for udf in MOZFUN_ROUTINES:
+            if udf["name"] in "\n".join(definitions):
+                dependencies.append(udf["name"])
 
         if is_defined:
-            if internal_name is None:
-                raise ValueError(
-                    f"Expected a UDF named {persistent_name} or {temp_name} "
-                    f"to be defined"
-                )
             dependencies.remove(internal_name)
 
         return RawUdf(
@@ -144,6 +168,7 @@ class RawUdf:
             # but then convert back to a list for stable order.
             sorted(set(dependencies)),
             description,
+            is_stored_procedure,
         )
 
 
@@ -167,7 +192,7 @@ def read_udf_dirs(*udf_dirs):
         for root, dirs, files in os.walk(udf_dir)
         if os.path.basename(root) != EXAMPLE_DIR
         for filename in files
-        if not filename.startswith(".") and filename.endswith(".sql")
+        if filename in (UDF_FILE, PROCEDURE_FILE)
         for raw_udf in (RawUdf.from_file(os.path.join(root, filename)),)
     }
 
@@ -218,9 +243,9 @@ def udf_usages_in_text(text):
     tmp_udfs = list(filter(lambda u: u != "udf_js", TEMP_UDF_RE.findall(sql)))
     udf_usages.extend(tmp_udfs)
 
-    for udf in MOZFUN_UDFS:
-        if udf in sql:
-            udf_usages.append(udf)
+    for routine in MOZFUN_ROUTINES:
+        if routine["name"] in sql:
+            udf_usages.append(routine["name"])
 
     return sorted(set(udf_usages))
 
@@ -240,15 +265,22 @@ def udf_usage_definitions(text, raw_udfs=None):
     ]
 
 
-def persistent_udf_as_temp(raw_udf, raw_udfs=None):
-    """Transform persistent UDF into temporary UDF."""
-    sql = prepend_udf_usage_definitions(raw_udf, raw_udfs)
+def sub_local_routines(test, raw_udfs=None):
+    """
+    Transform persistent UDFs into temporary UDFs.
+
+    Use generic dataset for stored procedures.
+    """
+    sql = prepend_udf_usage_definitions(test, raw_udfs)
     sql = sub_persistent_udf_names_as_temp(sql)
 
-    for udf in MOZFUN_UDFS:
-        if udf in sql:
-            sql = sql.replace(udf, udf.replace(".", "_"))
-    sql = sql.replace("mozfun.", "")
+    for routine in MOZFUN_ROUTINES:
+        if routine["name"] in sql:
+            replace_name = routine["name"].replace(".", "_")
+            if not routine["is_udf"]:
+                replace_name = GENERIC_DATASET + "." + replace_name
+            regex_str = r"(?:mozfun.)?" + routine["name"]
+            sql = re.sub(regex_str, replace_name, sql)
 
     sql = PERSISTENT_UDF_PREFIX.sub("CREATE TEMP FUNCTION", sql)
     return sql
@@ -263,7 +295,7 @@ def udf_tests_sql(raw_udf, raw_udfs):
     """
     tests_full_sql = []
     for test in raw_udf.tests:
-        test_sql = persistent_udf_as_temp(test, raw_udfs)
+        test_sql = sub_local_routines(test, raw_udfs)
         tests_full_sql.append(test_sql)
 
     return tests_full_sql
